summaryrefslogtreecommitdiffstats
path: root/src/server/internals/Note.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/internals/Note.hpp')
-rw-r--r--src/server/internals/Note.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/server/internals/Note.hpp b/src/server/internals/Note.hpp
index 6c7d9a13..290908e8 100644
--- a/src/server/internals/Note.hpp
+++ b/src/server/internals/Note.hpp
@@ -17,7 +17,7 @@
#ifndef INGEN_INTERNALS_NOTE_HPP
#define INGEN_INTERNALS_NOTE_HPP
-#include "NodeImpl.hpp"
+#include "BlockImpl.hpp"
#include "types.hpp"
namespace Ingen {
@@ -29,13 +29,13 @@ class InternalPlugin;
namespace Internals {
/** MIDI note input node.
*
* For pitched instruments like keyboard, etc.
*
* \ingroup engine
*/
-class NoteNode : public NodeImpl
+class NoteNode : public BlockImpl
{
public:
NoteNode(InternalPlugin* plugin,
@@ -29,13 +29,13 @@ class InternalPlugin;
namespace Internals {
-/** MIDI note input node.
+/** MIDI note input block.
*
* For pitched instruments like keyboard, etc.